@@ -621,6 +621,7 @@ class Scene(db.Model):
     end_frame = db.Column(db.Integer, nullable=False)
     start_time = db.Column(db.String(12), nullable=False)
     end_time = db.Column(db.String(12), nullable=False)
+    scene_file_name = db.Column(db.String(100), nullable=False)
     timestamp_added = db.Column(db.String(10), nullable=False)
 
     __table_args__ = (
@@ -640,8 +641,9 @@ class SceneObjects(db.Model):
     scene_object_id = db.Column(db.Integer, primary_key=True, autoincrement=True)
     video_id = db.Column(db.Integer, db.ForeignKey("videos.video_id"), nullable=False)
     scene_id = db.Column(db.Integer, db.ForeignKey("scenes.scene_id"), nullable=False)
+    video_frame_number = db.Column(db.Integer, nullable=False)
+    scene_frame_number = db.Column(db.Integer, nullable=False)
     object_number = db.Column(db.Integer, nullable=False)
-    frame_number = db.Column(db.Integer, nullable=False)
     object_x = db.Column(db.Integer, nullable=False)
     object_y = db.Column(db.Integer, nullable=False)
     object_w = db.Column(db.Integer, nullable=False)
@@ -652,8 +654,14 @@ class SceneObjects(db.Model):
     __table_args__ = (
         db.UniqueConstraint(
             "scene_id",
+            "scene_frame_number",
             "object_number",
-            "frame_number",
-            name="scene_object_frame",
+            name="scene_frame_object",
+        ),
+        db.UniqueConstraint(
+            "video_id",
+            "video_frame_number",
+            "object_number",
+            name="video_frame_object",
         ),
     )
